[][src]Struct rafx_api::RafxApiDefVulkan

pub struct RafxApiDefVulkan {
    pub app_name: Option<CString>,
    pub link_method: Option<VulkanLinkMethod>,
}

Vulkan-specific configuration

Fields

app_name: Option<CString>

Used as a hint for drivers for what is being run. There are no special requirements for this. It is not visible to end-users.

link_method: Option<VulkanLinkMethod>

Defines whether to load vulkan dynamically or use a statically-linked implementation. A common case where static linking is useful is linking MoltenVK on iOS devices