RafxShaderPackage

Struct RafxShaderPackage 

pub struct RafxShaderPackage {
    pub gles2: Option<RafxShaderPackageGles2>,
    pub gles3: Option<RafxShaderPackageGles3>,
    pub dx12: Option<RafxShaderPackageDx12>,
    pub metal: Option<RafxShaderPackageMetal>,
    pub vk: Option<RafxShaderPackageVulkan>,
    pub vk_reflection: Option<Vec<RafxReflectedEntryPoint>>,
    pub dx12_reflection: Option<Vec<RafxReflectedEntryPoint>>,
    pub metal_reflection: Option<Vec<RafxReflectedEntryPoint>>,
    pub gles2_reflection: Option<Vec<RafxReflectedEntryPoint>>,
    pub gles3_reflection: Option<Vec<RafxReflectedEntryPoint>>,
    pub debug_name: Option<String>,
}
Owns data necessary to create a shader module in (optionally) multiple APIs.

This struct can be serialized/deserialized and is intended to allow asset pipeline to store a shader module to be created at runtime. The package can optionally include data for multiple APIs allowing a single file to be used with whatever API is found at runtime.

Optionally, reflection data can be packaged along with shaders. Shaders may have platform-specific changes that produce different reflection data, so reflection is stored per-api

Fields

gles2: Option<RafxShaderPackageGles2>gles3: Option<RafxShaderPackageGles3>dx12: Option<RafxShaderPackageDx12>metal: Option<RafxShaderPackageMetal>vk: Option<RafxShaderPackageVulkan>vk_reflection: Option<Vec<RafxReflectedEntryPoint>>dx12_reflection: Option<Vec<RafxReflectedEntryPoint>>metal_reflection: Option<Vec<RafxReflectedEntryPoint>>gles2_reflection: Option<Vec<RafxReflectedEntryPoint>>gles3_reflection: Option<Vec<RafxReflectedEntryPoint>>debug_name: Option<String>

Implementations