[][src]Module rafx_api::vulkan

Structs

PhysicalDeviceInfo
RafxApiDefVulkan

Vulkan-specific configuration

RafxApiVulkan
RafxBufferRaw
RafxBufferVulkan
RafxCommandBufferVulkan
RafxCommandPoolVulkan
RafxDescriptorSetArrayVulkan
RafxDescriptorSetHandleVulkan
RafxDeviceContextVulkan
RafxDeviceContextVulkanInner
RafxFenceVulkan
RafxPipelineVulkan
RafxQueueVulkan
RafxRawImageVulkan
RafxRenderTargetVulkan
RafxRenderTargetVulkanInner
RafxRootSignatureVulkan
RafxSamplerVulkan
RafxSamplerVulkanInner
RafxSemaphoreVulkan
RafxShaderModuleVulkan
RafxShaderModuleVulkanInner
RafxShaderVulkan
RafxSwapchainVulkan

Represents a vulkan swapchain that can be rebuilt as needed

RafxTextureVulkan

Holds the vk::Image and allocation as well as a few vk::ImageViews depending on the provided RafxResourceType in the texture_def.

VkQueueFamilyIndices

Enums

PhysicalDeviceType

Used to specify which type of physical device is preferred. It's recommended to read the Vulkan spec to understand precisely what these types mean

VkPresentMode

Used to select which PresentMode is preferred. Some of this is hardware/platform dependent and it's a good idea to read the Vulkan spec.

VulkanLinkMethod

Determines the method of finding the vulkan loader

Constants

MAX_FRAMES_IN_FLIGHT

Functions

do_find_supported_format