[][src]Enum rafx_api::vulkan::PhysicalDeviceType

pub enum PhysicalDeviceType {
    Other,
    IntegratedGpu,
    DiscreteGpu,
    VirtualGpu,
    Cpu,
}

Used to specify which type of physical device is preferred. It's recommended to read the Vulkan spec to understand precisely what these types mean

Values here match VkPhysicalDeviceType, DiscreteGpu is the recommended default

Variants

Other

Corresponds to VK_PHYSICAL_DEVICE_TYPE_OTHER

IntegratedGpu

Corresponds to VK_PHYSICAL_DEVICE_TYPE_INTEGRATED_GPU

DiscreteGpu

Corresponds to VK_PHYSICAL_DEVICE_TYPE_DISCRETE_GPU

VirtualGpu

Corresponds to VK_PHYSICAL_DEVICE_TYPE_VIRTUAL_GPU

Cpu

Corresponds to VK_PHYSICAL_DEVICE_TYPE_CPU

Implementations

impl PhysicalDeviceType[src]

pub fn to_vk(self) -> PhysicalDeviceType[src]

Convert to vk::PhysicalDeviceType