[−][src]Enum rafx_api::vulkan::VkPresentMode
Used to select which PresentMode is preferred. Some of this is hardware/platform dependent and it's a good idea to read the Vulkan spec.
Fifo is always available on Vulkan devices that comply with the spec and is a good default for
many cases.
Values here match VkPresentModeKHR
Variants
(VK_PRESENT_MODE_IMMEDIATE_KHR) - No internal buffering, and can result in screen
tearin.
(VK_PRESENT_MODE_MAILBOX_KHR) - This allows rendering as fast as the hardware will
allow, but queues the rendered images in a way that avoids tearing. In other words, if the
hardware renders 10 frames within a single vertical blanking period, the first 9 will be
dropped. This is the best choice for lowest latency where power consumption is not a
concern.
(VK_PRESENT_MODE_FIFO_KHR) - Default option, guaranteed to be available, and locks
screen draw to vsync. This is a good default choice generally, and more power efficient
than mailbox, but can have higher latency than mailbox.
(VK_PRESENT_MODE_FIFO_RELAXED_KHR) - Similar to Fifo but if rendering is late,
screen tearing can be observed.
Implementations
impl VkPresentMode[src]
pub fn to_vk(self) -> PresentModeKHR[src]
Convert to vk::PresentModeKHR